aboutsummaryrefslogtreecommitdiffstats
path: root/sdnr/wt/netconfnode-state-service/model
diff options
context:
space:
mode:
authorhighstreetherbert <herbert.eiselt@highstreet-technologies.com>2021-04-29 19:06:54 +0200
committerKAPIL SINGAL <ks220y@att.com>2021-06-11 00:45:36 +0000
commitdb9f267b3930a28054e967c75db228e27663aedc (patch)
treee8ecaeff503afaa9c00b31781003b92a6f1844f2 /sdnr/wt/netconfnode-state-service/model
parente536aaa0422660283fa388c1a5d1a9c32dc52f9e (diff)
migrate features to silicon
migrate features to silicon Issue-ID: CCSDK-3278 Signed-off-by: highstreetherbert <herbert.eiselt@highstreet-technologies.com> Change-Id: Icabe6bd5b760438eedd8c6b78a70197c287c5199 Signed-off-by: highstreetherbert <herbert.eiselt@highstreet-technologies.com>
Diffstat (limited to 'sdnr/wt/netconfnode-state-service/model')
-rw-r--r--sdnr/wt/netconfnode-state-service/model/src/main/java/org/onap/ccsdk/features/sdnr/wt/netconfnodestateservice/NetconfDomAccessor.java10
1 files changed, 5 insertions, 5 deletions
diff --git a/sdnr/wt/netconfnode-state-service/model/src/main/java/org/onap/ccsdk/features/sdnr/wt/netconfnodestateservice/NetconfDomAccessor.java b/sdnr/wt/netconfnode-state-service/model/src/main/java/org/onap/ccsdk/features/sdnr/wt/netconfnodestateservice/NetconfDomAccessor.java
index 01d6659a5..aac6813f7 100644
--- a/sdnr/wt/netconfnode-state-service/model/src/main/java/org/onap/ccsdk/features/sdnr/wt/netconfnodestateservice/NetconfDomAccessor.java
+++ b/sdnr/wt/netconfnode-state-service/model/src/main/java/org/onap/ccsdk/features/sdnr/wt/netconfnodestateservice/NetconfDomAccessor.java
@@ -38,7 +38,7 @@ import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;
import org.opendaylight.yangtools.yang.data.api.YangInstanceIdentifier;
import org.opendaylight.yangtools.yang.data.api.schema.NormalizedNode;
-import org.opendaylight.yangtools.yang.model.api.SchemaPath;
+import org.opendaylight.yangtools.yang.model.api.stmt.SchemaNodeIdentifier.Absolute;
/**
* Interface handling netconf connection.
@@ -80,11 +80,11 @@ public interface NetconfDomAccessor extends NetconfAccessor {
*
* @param <T> specific child class of DOMNotificationListener
* @param listener listener to be called
* @param types as list of SchemaPath
* @return handler to manager registration
*/
<T extends DOMNotificationListener> @NonNull ListenerRegistration<DOMNotificationListener> doRegisterNotificationListener(
- @NonNull T listener, Collection<SchemaPath> types);
+ @NonNull T listener, Collection<Absolute> types);
/**
* Register netconf notification listener for related mountpoint
@@ -92,11 +92,11 @@ public interface NetconfDomAccessor extends NetconfAccessor {
* @See <a href="https://tools.ietf.org/html/rfc5277">https://tools.ietf.org/html/rfc5277</a>
* @param <T>
* @param listener to be registers
* @param types as array of SchemaPath
* @return Object to close and access
*/
<T extends DOMNotificationListener> @NonNull ListenerRegistration<DOMNotificationListener> doRegisterNotificationListener(
- @NonNull T listener, SchemaPath[] types);
+ @NonNull T listener, Absolute[] types);
/**
* Register netconf notification listener for related mountpoint
@@ -80,11 +80,11 @@ public interface NetconfDomAccessor extends NetconfAccessor {
* @param <T> specific child class of DOMNotificationListener
* @param listener listener to be called
- * @param types as list of SchemaPath
+ * @param types as list of Absolute
* @return handler to manager registration
*/
@@ -92,11 +92,11 @@ public interface NetconfDomAccessor extends NetconfAccessor {
* @param <T>
* @param listener to be registers
- * @param types as array of SchemaPath
+ * @param types as array of Absolute
* @return Object to close and access
*/